package com.tongran.rocketmq.service;

import java.util.List;
import com.tongran.rocketmq.domain.RmOutboundTrafficStatistics;

/**
 * 出省流量统计Service接口
 * 
 * @author tongran
 * @date 2026-01-21
 */
public interface IRmOutboundTrafficStatisticsService 
{
    /**
     * 查询出省流量统计
     * 
     * @param id 出省流量统计主键
     * @return 出省流量统计
     */
    public RmOutboundTrafficStatistics selectRmOutboundTrafficStatisticsById(Long id);

    /**
     * 查询出省流量统计列表
     * 
     * @param rmOutboundTrafficStatistics 出省流量统计
     * @return 出省流量统计集合
     */
    public List<RmOutboundTrafficStatistics> selectRmOutboundTrafficStatisticsList(RmOutboundTrafficStatistics rmOutboundTrafficStatistics);

    /**
     * 新增出省流量统计
     * 
     * @param rmOutboundTrafficStatistics 出省流量统计
     * @return 结果
     */
    public int insertRmOutboundTrafficStatistics(RmOutboundTrafficStatistics rmOutboundTrafficStatistics);

    /**
     * 修改出省流量统计
     * 
     * @param rmOutboundTrafficStatistics 出省流量统计
     * @return 结果
     */
    public int updateRmOutboundTrafficStatistics(RmOutboundTrafficStatistics rmOutboundTrafficStatistics);

    /**
     * 批量删除出省流量统计
     * 
     * @param ids 需要删除的出省流量统计主键集合
     * @return 结果
     */
    public int deleteRmOutboundTrafficStatisticsByIds(Long[] ids);

    /**
     * 删除出省流量统计信息
     * 
     * @param id 出省流量统计主键
     * @return 结果
     */
    public int deleteRmOutboundTrafficStatisticsById(Long id);
}
